/**********************************************************************
* 
* report.h
*
* This file is part of MitoGen
* 
* Copyright (C) 2013-2017 -- Centre for Biomedical Image Analysis (CBIA)
* http://cbia.fi.muni.cz/
* 
* MitoGen is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
* 
* MitoGen is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License
* along with MitoGen. If not, see <http://www.gnu.org/licenses/>.
* 
* Author: David Wiesner
* 
* Description: Definition of methods of class 'ReportHead' that generates
* headers for REPORTs in multi-threaded implementation of MitoGen.
*
***********************************************************************/


#ifdef GTGEN_WITH_MULTITHREADING


#include "report.h"


void ReportHead::MakeReport() const
{
	using namespace std;
	
	if (numOfThreads != 0)
	{
		const report_clock::time_point currentTime_st = report_clock::now();
		const report_clock::duration runTime_st = currentTime_st - startTime_st;
		
		const chrono::milliseconds runTime_msec_st = 
			chrono::duration_cast<chrono::milliseconds>(runTime_st); 
		const chrono::hours hh =
			chrono::duration_cast<chrono::hours>(runTime_msec_st);
		const chrono::minutes mm =
			chrono::duration_cast<chrono::minutes>(runTime_msec_st % chrono::hours(1));
		const chrono::seconds ss =
			chrono::duration_cast<chrono::seconds>(runTime_msec_st % chrono::minutes(1));
		const chrono::milliseconds msec =
			chrono::duration_cast<chrono::milliseconds>(runTime_msec_st % chrono::seconds(1));

		cout << "Thread " << thrID << " at " << setfill('0') 	
			<< setw(2) << hh.count() << ":" 
			<< setw(2) << mm.count() << ":"
			<< setw(2) << ss.count() << ":"
			<< setw(3) << msec.count() << ", ";
							       			
		// if thread currently processes a cell					       			
		if (threadCellInfo[thrID] != SIZE_MAX)
			cout << "Cell ID: " << threadCellInfo[thrID] << ",";
		
		cout << endl;
	}
}


#endif


